@@ -5,10 +5,10 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.301001_056';
+our $VERSION = '1.301001_057';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
-use Test::Stream;
+use Test::Stream '-internal';
 use Test::Stream::Toolset;
 
 use Test::Stream::Exporter;
